*Creates the graph for the Journal of Economic Perspectives piece, 
*Reference: "Why do management practices differ across firms and countries?", Nicholas Bloom and John Van Reenen, Journal of Economic Perspectives, Volume 1, 2010.
*Any questions please contact nbloom@stanford.edu

clear all
set mem 250m
set more off

cap log close
log using jep_replicate,replace t
***********************************************************
*First start by defining all the variables in both datasets
***********************************************************
u panel_data,clear
de

u basic,clear
de

***********************************************************
*Now replicate some results from the JEP paper
***********************************************************
*Figure 1: Uses data from 2006-2008 survey wave
graph hbar management [aw=(1-0.66*orbis)],over(country,sort(1) reverse) exclude0 ylab(2.6(0.2)3.4)

*Table 2
egen monitoring=rmean(lean1 lean2 perf1 perf2 perf3 perf4)
cap egen targets=rmean(perf6 perf7 perf8 perf9 perf10)
egen incentives=rmean(perf5 talent*) 
tab country [aw=(1-0.66*orbis)],su(management)
tab country [aw=(1-0.66*orbis)],su(monitoring)
tab country [aw=(1-0.66*orbis)],su(targets)
tab country [aw=(1-0.66*orbis)],su(incentives)

*Figure 2: Uses data from 2006-2008 survey wave
u basic,clear
replace country=" US" if country=="US"
replace country="Ireland" if country=="Northern Ireland"|country=="Republic of Ireland"
replace country="Southern Europe" if country=="Greece"|country=="Portugal"
replace cty="seu" if country=="Southern Europe"
gen US=(cty=="us")
qui ksmirnov management ,by(US)
gen count=1
so cty
by cty:replace count=count[_n-1]+1 if count[_n-1]~=.
cap qui kdensity management if cty=="us", generate(US_x US_y) n(100)
egen USx=max(US_x),by(count)
egen USy=max(US_y),by(count)
graph twoway  (histogram  management, bin(25) by(country) legend(off)) if country==" US"|country=="India"|country=="Brazil"|country=="China"|country=="France"|country=="Southern Europe" || (scatter USy USx, by(country) c(d) s(p) lc(black) legend(off))

*Table 3 - performance regressions. Combines 2004 and 2006-2008 data
*NOTE THAT BECAUSE I HAVE UPDATED SOME OF THE DATA THIS WILL NOT EXACTLY REPLICATE THE RESULTS FROM THE PAPER, BUT IS QUALITATIVELY SIMILAR
u panel_data,clear
qui tab year,gen(yy)
qui tab cty,gen(cc)
qui tab analyst,gen(aa)
qui tab dow,gen(dd)
global noise "aa* reliability i_comptenure* dd* i_sen* duration*  hour hourmiss"
global general "public lfirmage hourst*"
areg lq_a                        management cc* $noise  $general yy* old,ab(sic) cluster(company_id)

*Column 1
reg lsales  lemp                 management                     yy* old,        cluster(company_id)
*Column 2
areg lsales lemp                 management cc*                 yy* old,ab(sic) cluster(company_id)
*Column 3
areg lsales lemp lpp* ldegree_t* management cc* $noise $general yy* old,ab(sic) cluster(company_id)
*Column 5
areg roce_a                      management cc* $noise $general yy* old,ab(sic) cluster(company_id)
*Column 6
areg lq_a                        management cc* $noise  $general yy* old,ab(sic) cluster(company_id)
*Column 7
areg dsales5_a                   management cc* $noise  $general yy* old,ab(sic) cluster(company_id)

*Column A - extra column of results
replace patenttot=0 if patenttot==.
gen lpatenttot=log(1+patenttot)
so company_id year
areg lpat                        management cc* $noise  $general old if company_id~=company_id[_n-1],ab(sic) cluster(company_id)
                        

*Figure 3: Labor laws: Uses data from 2006-2008 survey wave
u basic,clear
cap drop people
egen incentives=rmean(perf5 talent*) 
egen incentives_mean=mean(incentives),by(country)
so cty
graph twoway (scatter incentives_mean wb_rigiditye if cty~=cty[_n-1],ml(country))  (lfit incentives_mean wb_rigiditye if cty~=cty[_n-1] ), legend(off)
egen monitoring=rmean(lean1 lean2 perf1 perf2 perf3 perf4)
egen monitoring_mean=mean(monitoring),by(country)
egen targets=rmean(perf6 perf7 perf8 perf9 perf10)
egen targets_mean=mean(targets),by(country)
so country
pwcorr incentives_ monitoring_ targets_ wb_rigiditye if country~=country[_n-1],sig

*Figure 4: Ownership: Uses data from 2006-2008 survey wave
u basic,clear
gen count=1
so ownership
drop if ownership==""
by ownership:replace count=count[_n-1]+1 if count[_n-1]~=.
qui kdensity management if ownership=="5+ Shareholders", generate(PE_x PE_y) n(100)
egen PEx=max(PE_x),by(count)
egen PEy=max(PE_y),by(count)
drop if ownership=="Other"
*Note, have to change graph start editor, under graph, aspect ration, organization, select 4 columns and downfirst to get this looking like the paper. 
graph twoway  (histogram  management, bin(25) by(ownership)) || (scatter PEy PEx, by(ownership) c(d) s(p) lc(black))

*Figure 5: Multinationals and domestic: Uses data from 2006-2008 survey wave
u basic,clear
gen multi=(MNE_o<=1)
egen _multi_man=mean(management) if multi==1,by(country)
egen multi_man=max(_multi_man),by(country)
graph hbar management multi_man if MNE_o==3,over(country,sort(1) reverse) exclude0
log close


*If you want to combine the two datesets together to run more extensive panel regresssion need to merge by code analyst date because some firms had double interviews
u basic,clear
merge 1:m code analyst date using panel_data
*Note: those with _m==1 are the firms with no account data, those with _m==2 are the 2004 survey firms for which we are not releasing the management data breakdown


*This creates the *.csv files in this folder, which non-stata using folks find useful
u basic,clear
outsheet using basic.csv,c names replace
u panel_data,clear
outsheet using panel_data.csv,c names replace

